<?php
/**
 * Assets and Block Registration Class
 *
 * @package wpRigel\TableStack
 */

namespace wpRigel\TableStack;

/**
 * Class Assets
 */
class Assets {

	/**
	 * Singleton instance
	 *
	 * @var Assets
	 */
	private static $instance;

	/**
	 * Get the singleton instance.
	 *
	 * @return Assets
	 */
	public static function get_instance(): Assets {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor.
	 */
	private function __construct() {
		add_action( 'init', [ $this, 'register_blocks' ] );
		add_action( 'init', [ $this, 'register_block_styles' ] );
		add_action( 'enqueue_block_editor_assets', [ $this, 'localize_script' ] );
	}

	/**
	 * Register the Gutenberg blocks.
	 *
	 * @return void
	 */
	public function register_blocks(): void {
		register_block_type( TABLESTACK_PATH . '/build' );
		register_block_type( TABLESTACK_PATH . '/build/table-cell' );
		register_block_type( TABLESTACK_PATH . '/build/table-row' );
		register_block_type( TABLESTACK_PATH . '/build/table' );
		register_block_type( TABLESTACK_PATH . '/build/woo-table' );
	}

	/**
	 * Register block styles.
	 */
	public function register_block_styles() {
		$block_styles = [
			[
				'block' => 'tablestack/table',
				'style' => [
					'name'  => 'rounded-table',
					'label' => __( 'Rounded Table', 'table-stack' ),
				],
			]
		];

		foreach ( $block_styles as $block_style ) {
			register_block_style( $block_style['block'], $block_style['style'] );
		}
	}

	/**
	 * Localize script.
	 */
	public function localize_script() {

		$permitted_blocks = apply_filters('table_stack_cell_permitted_blocks', [
			"core/paragraph",
			"core/button",
			"core/image",
			"core/list",
		]);

		wp_localize_script(
			'tablestack-tablewrapper-editor-script',
			'tableStackConfig',
            array(
				'permittedBlocks' => $permitted_blocks,
			)
		);
	}
}
