<?php
/**
 * Main Plugin Class
 *
 * @package wpRigel\TableStack
 */

namespace wpRigel\TableStack;

/**
 * Class Plugin
 */
class Plugin {

	/**
	 * Plugin directory path.
	 *
	 * @var string
	 */
	protected $path;

	/**
	 * Plugin URL.
	 *
	 * @var string
	 */
	protected $url;

	/**
	 * Initialize the plugin.
	 *
	 * @return void
	 */
	public function run(): void {
		$this->load_dependencies();
		$this->load_hooks();
	}

	/**
	 * Load required dependencies.
	 *
	 * @return void
	 */
	protected function load_dependencies(): void {
		require_once TABLESTACK_PATH . '/includes/class-assets.php';
	}

	/**
	 * Load the plugin hooks.
	 *
	 * @return void
	 */
	protected function load_hooks(): void {
		add_filter( 'plugin_row_meta', [ $this, 'plugin_row_meta' ], 10, 2 );
		Assets::get_instance();
	}

	/**
	 * Add plugin row meta links.
	 *
	 * @param array  $links Plugin row meta links.
	 * @param string $file  Plugin base file.
	 *
	 * @return array
	 */
	public function plugin_row_meta( array $links, string $file ): array {
		if ( plugin_basename( TABLESTACK_PATH . '/table-block.php' ) === $file ) {
			$row_meta = [
				'get-started' => '<a href="https://wprigel.com/table-stack/" target="_blank" aria-label="' . esc_attr__( 'Get started', 'table-block' ) . '">' . esc_html__( 'Get started', 'table-block' ) . '</a>',
				'docs'        => '<a href="https://wprigel.com/docs/table-stack/" target="_blank" aria-label="' . esc_attr__( 'Documentation', 'table-block' ) . '">' . esc_html__( 'Documentation', 'table-block' ) . '</a>',
			];

			return array_merge( $links, $row_meta );
		}

		return $links;
	}
}
