import { useBlockProps, useInnerBlocksProps } from '@wordpress/block-editor';

export default function save({attributes}) {
    const {
        columnOnlyBorder,
        evenRowBackground,
        oddRowBackground,
        headerRowBackground,
        headerRowTextColor,
        oddRowTextColor,
        evenRowTextColor,
        tdPadding,
        verticalAlignment,
        horizontalAlignment,
        tableBorder,
        cellBorder,
        showColumnOnlyBorder
    } = attributes;

    const style = {
        '--tablestack-cell-vertical-alignment': verticalAlignment,
        '--tablestack-cell-horizontal-alignment': horizontalAlignment,
        '--tablestack-even-row-bg-color': evenRowBackground,
        '--tablestack-odd-row-bg-color': oddRowBackground,
        '--tablestack-header-row-bg-color': headerRowBackground,
        '--tablestack-header-row-text-color': headerRowTextColor,
        '--tablestack-odd-row-text-color': oddRowTextColor,
        '--tablestack-even-row-text-color': evenRowTextColor,
        '--tablestack-padding-top': tdPadding?.top || '0px',
        '--tablestack-padding-bottom': tdPadding?.bottom || '0px',
        '--tablestack-padding-left': tdPadding?.left || '0px',
        '--tablestack-padding-right': tdPadding?.right || '0px',
        '--tablestack-table-border-style': tableBorder?.style,
        '--tablestack-table-border-color': tableBorder?.color,
        '--tablestack-table-border-width': tableBorder?.width,
        '--tablestack-table-cell-border-style': cellBorder?.style,
        '--tablestack-table-cell-border-color': cellBorder?.color,
        '--tablestack-table-cell-border-width': cellBorder?.width,
        '--tablestack-column-only-border-style': showColumnOnlyBorder ? columnOnlyBorder?.style : '',
        '--tablestack-column-only-border-color': showColumnOnlyBorder ? columnOnlyBorder?.color : '',
        '--tablestack-column-only-border-width': showColumnOnlyBorder ? columnOnlyBorder?.width : '',
    };
    const blockProps = useBlockProps.save({style});
    const innerBlocks = useInnerBlocksProps.save();

    return (
        <table {...blockProps}>
            <tbody {...innerBlocks} />
        </table>
    );
}
