import { useBlockProps } from '@wordpress/block-editor';

export default function save({ attributes }) {
    const { 
      tableVisibleColumns, 
      tableColumnOrder, 
      blockType,
      categories,
      tags,
      order,
      orderBy,
      type,
      productStatus,
      numberOfItems,
      verticalAlignment,
      horizontalAlignment,
      showSearchInput,
      productImageSize,
      searchInputWidth,
      searchInputPosition,
      noDataMessage,
      cartButtonBgColor,
		  cartButtonTextColor,
		  cartButtonHoverBgColor,
		  cartButtonHoverTextColor,
      paginateButtonBgColor,
      paginateButtonTextColor,
      paginateButtonHoverBgColor,
      paginateButtonHoverTextColor,
      paginateButtonDisabledColor,
    } = attributes;

    const style = {
      '--tablestack-even-row-bg-color': attributes.evenRowBackground,
      '--tablestack-odd-row-bg-color': attributes.oddRowBackground,
      '--tablestack-header-row-bg-color': attributes.headerRowBackground,
      '--tablestack-padding-top': attributes.tdPadding?.top || '0px',
      '--tablestack-padding-bottom': attributes.tdPadding?.bottom || '0px',
      '--tablestack-padding-left': attributes.tdPadding?.left || '0px',
      '--tablestack-padding-right': attributes.tdPadding?.right || '0px',
		  '--tablestack-cell-horizontal-alignment': horizontalAlignment,
		  '--tablestack-cell-vertical-alignment': verticalAlignment,
		  '--tablestack-product-image-size': productImageSize,
      '--tablestack-search-input-width': searchInputWidth,
		  '--tablestack-search-input-position': searchInputPosition,
      '--tablestack-cart-button-bg-color': cartButtonBgColor,
      '--tablestack-cart-button-hover-bg-color': cartButtonHoverBgColor,
      '--tablestack-cart-button-text-color': cartButtonTextColor,
      '--tablestack-cart-button-hover-text-color': cartButtonHoverTextColor,
      '--tablestack-paginate-button-bg-color': paginateButtonBgColor,
		  '--tablestack-paginate-button-text-color': paginateButtonTextColor,
      '--tablestack-paginate-button-hover-bg-color': paginateButtonHoverBgColor,
		  '--tablestack-paginate-button-hover-text-color': paginateButtonHoverTextColor,
		  '--tablestack-paginate-button-disabled-color': paginateButtonDisabledColor,
    };

    const tableVisibilityString = JSON.stringify(tableVisibleColumns);
    const tableColumnsString = JSON.stringify(tableColumnOrder);
    const showTableSearchInput = JSON.stringify(showSearchInput);
    const productCategories = JSON.stringify(categories);
    const productTags = JSON.stringify(tags);
    const productOrder = JSON.stringify(order);
    const productOrderBy = JSON.stringify(orderBy);
    const productType = JSON.stringify(type);
    const pStatus = JSON.stringify(productStatus);
    const productPerPage = JSON.stringify(numberOfItems);
    const customMessage = JSON.stringify(noDataMessage);

    return (
    <div { ...useBlockProps.save({style}) }>
        <div className="tablestack-wootable"
          data-table-visibility={tableVisibilityString}
          data-table-columns={tableColumnsString}
          data-table-search={showTableSearchInput}
          data-block-type={blockType}
          data-block-productcategories={productCategories}
          data-block-producttags={productTags}
          data-block-productorder={productOrder}
          data-block-productorderby={productOrderBy}
          data-block-producttype={productType}
          data-block-productstatus={pStatus}
          data-block-productperpage={productPerPage}
          data-block-custommessage={customMessage}
        >
        </div>
    </div>
    );
}
